@@ -3,7 +3,6 @@ package File::FormatIdentification::Pronom;
 use feature qw(say);
 use strict;
 use warnings;
-use diagnostics;
 use XML::LibXML;
 use Carp;
 use List::Util qw( none first );
@@ -12,7 +11,9 @@ use YAML::XS;
 use File::FormatIdentification::Regex;
 use Moose;
 
-our $VERSION = '0.02';
+our $VERSION = '0.05'; # TRIAL VERSION
+
+# ABSTRACT Perl extension for parsing PRONOM-Signatures using DROID-Signature file
 
 # Preloaded methods go here.
 # flattens a regex-structure to a regex-string, expects a signature-pattern and a list of regex-structures
@@ -950,11 +951,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
-# Below is stub documentation for your module. You'd better edit it!
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-File::FormatIdentification::Pronom - Perl extension for parsing Pronom-Signatures using DROID-Signature file
+File::FormatIdentification::Pronom
+
+=head1 VERSION
+
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -962,43 +970,112 @@ File::FormatIdentification::Pronom - Perl extension for parsing Pronom-Signature
   my $pronomfile = "Droid-Signature.xml";
   my ( $signatures, $internals ) = parse_signaturefile($pronomfile);
 
-
 =head1 DESCRIPTION
 
-Stub documentation for File::FormatIdentification::Pronom, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
+The module allows to handle Droid signatures. Droid is a utility which
+uses the PRONOM database to identify file formats.
 
-Blah blah blah.
+See https://www.nationalarchives.gov.uk/PRONOM/ for details.
+
+With this module you could:
+
+=over
+
+=item convert Droid signatures to Perl regular expressions
+
+=item analyze files and display which/where pattern of Droid signature matches  via tag-files for wxHexEditor
+
+=item calc statistics about Droid signatures
+
+=back
+
+The module is in early alpha state and should not be used in production.
+
+=head2 Examples
+
+=head3 Colorize wxHexeditor fields
+
+See example file F<bin/pronom2wxhexeditor.pl>. This colorizes the hex-blob to check PRONOM pattern matches for a given file.
+
+=head3 Identify file
+
+There are better tools for the job, but as a proof of concept certainly not bad: Identifying the file type of a file.
+
+  my $pronom = File::FormatIdentification::Pronom->new(
+    "droid_signature_filename" => $pronomfile
+  );
+  # .. $filestream is a scalar representing a file
+  foreach my $internalid ( $pronom->get_all_internal_ids() ) {
+      my $sig = $pronom->get_signature_id_by_internal_id($internalid);
+      my $puid = $pronom->get_puid_by_signature_id($sig);
+      my $name = $pronom->get_name_by_signature_id($sig);
+      my $quality = $pronom->get_qualities_by_internal_id($internalid);
+      my @regexes = $pronom->get_regular_expressions_by_internal_id($internalid);
+      if ( all {$filestream =~ m/$_/saa} @regexes ) {
+          say "$binaryfile identified as $name with PUID $puid (regex quality $quality)";
+      }
+  }
+
+See example file F<bin/pronomidentify.pl> for a  full working script.
+
+=head3 Get PRONOM Statistics
+
+To get a feeling for which signatures need to be revised in PRONOM, or why which file formats are difficult to recognize,
+you can get detailed statistics for given signature files.
+
+In the blog entry under L<https://kulturreste.blogspot.com/2018/10/heres-tool-make-it-work.html> the statistic report is presented in more detail.
 
 =head2 EXPORT
 
 None by default.
 
+=head1 NAME
 
+File::FormatIdentification::Pronom - Perl extension for parsing PRONOM-Signatures using DROID-Signature file
 
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+L<File::FormatIdentification::Regex>
 
 =head1 AUTHOR
 
-art1
+Andreas Romeyke L<pause@andreas-romeyke.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018/19 by art1
+Copyright (C) 2018/19/20 by Andreas Romeyke
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.24.1 or,
 at your option, any later version of Perl 5 you may have available.
 
+The droid-signature file in t/ is from L<https://www.nationalarchives.gov.uk/PRONOM/Default.aspx>
+and without guarantee, it does not look like it is legally protected. If there are any legal claims,
+please let me know that I can remove them from the distribution.
+
+=head1 BUGS
+
+=over
+
+=item Some droid recipes results in PCREs which are greedy and therefore the running
+  time could be exponential with size of binary file.
+
+=back
+
+=head1 CONTRIBUTING
+
+Please feel free to send me comments and patches to my email address. You can clone the modules
+from L<https://art1pirat.spdns.org/art1/File-FormatIdentification-Pronom> and send me merge requests.
+
+=head1 AUTHOR
+
+Andreas Romeyke <pause@andreas-romeyke.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Andreas Romeyke.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
